@@ -1,17 +1,20 @@
-use clap::Subcommand;
 use std::io::Result;
 
-use crate::std_err;
-use crate::{db::EnvelopeDb, ops};
+use clap::Subcommand;
+
+use crate::db::EnvelopeDb;
+use crate::{ops, std_err};
 
 mod add;
 mod delete;
+mod diff;
 mod drop;
 mod duplicate;
 mod edit;
-mod export;
+mod history;
 mod import;
 mod list;
+mod revert;
 
 #[derive(Subcommand)]
 #[command(infer_subcommands = true)]
@@ -27,16 +30,20 @@ pub enum EnvelopeCmd {
 
     Duplicate(duplicate::Cmd),
 
-    Export(export::Cmd),
+    Diff(diff::Cmd),
 
     Edit(edit::Cmd),
 
+    History(history::Cmd),
+
     /// Initialize envelope
     Init,
 
     Import(import::Cmd),
 
     List(list::Cmd),
+
+    Revert(revert::Cmd),
 }
 
 impl EnvelopeCmd {
@@ -51,10 +58,12 @@ impl EnvelopeCmd {
             Self::Delete(delete) => delete.run(&db).await?,
             Self::Drop(drop) => drop.run(&db).await?,
             Self::Duplicate(duplicate) => duplicate.run(&db).await?,
-            Self::Export(export) => export.run(&db).await?,
+            Self::Diff(diff) => diff.run(&db).await?,
             Self::Edit(edit) => edit.run(&db).await?,
             Self::Import(import) => import.run(&db).await?,
+            Self::History(history) => history.run(&db).await?,
             Self::List(list) => list.run(&db).await?,
+            Self::Revert(revert) => revert.run(&db).await?,
             _ => {}
         }
 
