@@ -1,17 +1,21 @@
 mod add;
 mod check;
 mod delete;
+mod diff;
 mod drop;
 mod duplicate;
 mod edit;
-mod export;
+mod history;
 mod list;
+mod revert;
 
 pub use add::*;
 pub use check::*;
 pub use delete::*;
+pub use diff::*;
 pub use drop::*;
 pub use duplicate::*;
 pub use edit::*;
-pub use export::*;
+pub use history::*;
 pub use list::*;
+pub use revert::*;
